Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2532)

Unified Diff: appengine/findit/model/flake/flake_analysis_request.py

Issue 2396283002: [Findit] Hook up analysis for CQ flakes. (Closed)
Patch Set: Fix nit Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: appengine/findit/model/flake/flake_analysis_request.py
diff --git a/appengine/findit/model/flake/flake_analysis_request.py b/appengine/findit/model/flake/flake_analysis_request.py
index 1c9c4f9244478c7c6df195d04096ab20a7a7230d..ccef2c153f1b39f22a12cc4501d3130f02b0c85f 100644
--- a/appengine/findit/model/flake/flake_analysis_request.py
+++ b/appengine/findit/model/flake/flake_analysis_request.py
@@ -36,8 +36,8 @@ class BuildStep(ndb.Model):
# Indicate whether analysis on the step is supported.
supported = ndb.BooleanProperty(indexed=False, default=False)
- # Indicate whether the flake on this configuration is analyzed.
- analyzed = ndb.BooleanProperty(indexed=False, default=False)
+ # Indicate whether the analysis of flake on this configuration is scheduled.
+ scheduled = ndb.BooleanProperty(indexed=False, default=False)
@staticmethod
def _StripMasterPrefix(name):
@@ -119,3 +119,12 @@ class FlakeAnalysisRequest(VersionedModel):
BuildStep.Create(
master_name, builder_name, build_number, step_name, reported_time))
return True
+
+ def CopyFrom(self, other):
+ """Copies all states from the given request."""
+ assert isinstance(other, FlakeAnalysisRequest)
+ self.is_step = other.is_step
+ self.bug_id = other.bug_id
+ self.user_emails = other.user_emails
+ self.build_steps = other.build_steps
+ self.analyses = other.analyses
« no previous file with comments | « appengine/findit/common/constants.py ('k') | appengine/findit/model/flake/test/flake_analysis_request_test.py » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698